SingleThreadedDispatcher

Struct SingleThreadedDispatcher 

pub(crate) struct SingleThreadedDispatcher {
    bucketer: RefCell<CommandBucketer>,
    viewport: ViewportState,
    recorder: CommandRecorder<RecordedFill>,
    strip_storage: StripStorage,
    level: Level,
}
Single-threaded implementation of the rendering dispatcher.

Fields

bucketer: RefCell<CommandBucketer>

Reusable coarse bucketer that converts recorded commands into per-row render commands.

viewport: ViewportState

Viewport state.

recorder: CommandRecorder<RecordedFill>

Recorder for root and filter-layer command streams, plus layer metadata.

strip_storage: StripStorage

Storage for generated strips and alpha coverage data.

level: Level

SIMD level for fearless SIMD dispatch.

Implementations

Source

impl SingleThreadedDispatcher

pub(crate) fn new(width: u16, height: u16, level: Level) -> Self

Creates a new single-threaded dispatcher for the given dimensions.

Arguments
  • width - Width of the rendering surface in pixels.
  • height - Height of the rendering surface in pixels.
  • level - SIMD level to use for rasterization.
fn rasterize_u8( &self, target: PixmapMut<'_>, scene_width: u16, scene_height: u16, settings: RasterizerSettings, encoded_paints: &[EncodedPaint], image_resolver: &dyn ImageResolver, )

Rasterizes the scene using u8 precision (fast).

This dispatches to the appropriate SIMD implementation based on the configured level, using u8 for intermediate calculations to maximize speed.

fn rasterize_with<S: Simd, F: FineKernel<S>>( &self, simd: S, target: PixmapMut<'_>, scene_width: u16, scene_height: u16, settings: RasterizerSettings, encoded_paints: &[EncodedPaint], image_resolver: &dyn ImageResolver, )

fn bucket_and_rasterize<S: Simd, F: FineKernel<S>>( &self, simd: S, cmds: &[Node], viewport: RectU16, filter_ctx: &FilterContext, target: PixmapMut<'_>, params: FineRenderParams, use_src_over: bool, encoded_paints: &[EncodedPaint], image_resolver: &dyn ImageResolver, )

fn rasterize_target<S: Simd, F: FineKernel<S>>( simd: S, bucketer: &CommandBucketer, resources: FineResources<'_>, regions: &mut Regions<'_>, use_src_over: bool, )

fn record_fill( &mut self, strip_start: usize, paint: Paint, blend_mode: BlendMode, mask: Option<Mask>, )

fn rasterize_filter_layers<S: Simd, F: FineKernel<S>>( &self, simd: S, encoded_paints: &[EncodedPaint], image_resolver: &dyn ImageResolver, ) -> FilterContext